API
===
Import graphvelo as::

    import graphvelo
    import graphvelo.plot

Core
~~~~

.. module:: graphvelo.graph_velocity
.. currentmodule:: graphvelo
.. autosummary::
    :toctree: api

    graph_velocity.GraphVelo

GAM
~~~~

.. module:: graphvelo.gam
.. currentmodule:: graphvelo.gam
.. autosummary::
    :toctree: api

    fit_velo_peak
    fit_gene_trend
    fit_response